BrainFlow plugin
================

This plugin provides a unified interface for all boards supported by `BrainFlow <https://brainflow.readthedocs.io/en/stable/>`__.

Installation
------------

First, make sure that `Timeflux <https://github.com/timeflux/timeflux>`__ is installed.

You can then install this plugin in the `timeflux` environment:

::

    $ conda activate timeflux
    $ pip install timeflux_brainflow
